@@ -1,10 +1,14 @@
 package Log::ger::Layout;
 
-our $DATE = '2017-07-30'; # DATE
-our $VERSION = '0.020'; # VERSION
+our $DATE = '2017-08-02'; # DATE
+our $VERSION = '0.021'; # VERSION
 
 use parent qw(Log::ger::Plugin);
 
+# we only use one output, so set() should replace all hooks from previously set
+# plugin package
+sub _replace_package_regex { qr/\ALog::ger::Output::/ }
+
 1;
 # ABSTRACT: Use a layout plugin
 
@@ -20,7 +24,7 @@ Log::ger::Layout - Use a layout plugin
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
